@@ -52,7 +52,7 @@ mledist <- function (data, distr, start=NULL, fix.arg=NULL, optim.method="defaul
     {
       if(any(weights < 0))
         stop("weights should be a vector of integers greater than 0")
-      if(!is.allint.w(weights))
+      if(!isallintw(weights))
         stop("weights should be a vector of (strictly) positive integers")
       if(length(weights) != NROW(data))
         stop("weights should be a vector with a length equal to the observation number")
