@@ -1,12 +1,13 @@
 library(fitdistrplus)
 nbboot <- 100
 nbboot <- 10
+nsample <- 10
 
 # (1) Description of a sample from a normal distribution
 # with and without uncertainty on skewness and kurtosis estimated by bootstrap 
 #
 set.seed(1234)
-x1 <- rnorm(100)
+x1 <- rnorm(nsample)
 descdist(x1)
 descdist(x1,boot=nbboot)
 
@@ -14,19 +15,19 @@ descdist(x1,boot=nbboot)
 # with uncertainty on skewness and kurtosis estimated by bootstrap
 # with changing of default colors 
 #
-descdist(rbeta(100,shape1=0.05,shape2=1),boot=nbboot,
+descdist(rbeta(nsample,shape1=0.05,shape2=1),boot=nbboot,
 obs.col="blue",boot.col="orange")
 
 # (3) Description of a sample from a gamma distribution
 # with uncertainty on skewness and kurtosis estimated by bootstrap
 # without plotting 
 #
-descdist(rgamma(100,shape=2,rate=1),boot=nbboot,graph=FALSE)
+descdist(rgamma(nsample,shape=2,rate=1),boot=nbboot,graph=FALSE)
 
 # (3) Description of a sample from a Poisson distribution
 # with uncertainty on skewness and kurtosis estimated by bootstrap 
 #
-descdist(rpois(100,lambda=2),discrete=TRUE,boot=nbboot)
+descdist(rpois(nsample,lambda=2),discrete=TRUE,boot=nbboot)
 
 # (4) Description of serving size data
 # with uncertainty on skewness and kurtosis estimated by bootstrap 
